django-workon
======================

Django multi extensions

- Urls routing by decorator
- Utils
- Fields
- Form Fields
- Models helpers
- Contribs

Usage
=====

Add ``'workon'`` to your INSTALLED_APPS
Add ``url(r'^whatever_internal/', include('workon.urls')),`` to your url PATTERNS



